@@ -6,7 +6,7 @@ import datetime
 import requests
 from colorama import *
 def capes(email, password):
-    text = login_acc.login(email, password)
+    text = login_acc(email, password)
     token = text["access_token"]
 
     headers = {"Content-type": "application/json", "Authorization": "Bearer " + token}
